@@ -53,8 +53,8 @@ hotel2T2 <- function(x1, x2, a = 0.05, R = 999, graph = FALSE) {
     vb2 <- vector("list", B)
     tb <- matrix(0, B, B)
     for (i in 1:B) {
-      b1 <- sample(1:n1, n1, replace = TRUE)
-      b2 <- sample(1:n2, n2, replace = TRUE)
+      b1 <- Rfast2::Sample.int(n1, n1, replace = TRUE)
+      b2 <- Rfast2::Sample.int(n2, n2, replace = TRUE)
       yb1 <- y1[b1, ]    ;   yb2 <- y2[b2, ]
       bm1[i, ] <- Rfast::colmeans(yb1)
       bm2[i, ] <- Rfast::colmeans(yb2)  ## difference of the mean vectors
